# Kegbot

This is the main code repository for the Kegbot Server package.
(Or it might be a fork.  The official repository lives here:
https://github.com/Kegbot/kegbot).

## Quick start

Super quick start instructions:

```
$ mkvirtualenv kb
(kb) $ pip install kegbot
(kb) $ setup-kegbot.py
(kb) $ kegbot runserver
Development server is running at http://localhost:8000/
```

For much more detail, see the complete [Kegbot Server documentation](http://kegbot.org/docs/server/).

## Documentation and Help

Please see our main website, http://kegbot.org/, for
[documentation](http://kegbot.org/docs), the
[Kegbot Forum](http://kegbot.org/kegbb/), and the
[Kegbot Blog](http://kegbot.org/blog/).

You can also find us on **#kegbot** on freenode IRC.

You should definitely follow [@kegbot](http://twitter.com/kegbot) on
Twitter, all the cool kids are.


## Kegboard

Firmware and schematics for Kegboard, our Arduino kegerator controller package,
can now be found in a new repository: https://github.com/Kegbot/kegboard/


## License and Copyright

All code is offered under the **GPLv2** license, unless otherwise noted.
Please see ``LICENSE.txt`` for the full license.

All code and documentation are **Copyright 2003-2012 Mike Wakerly**,
unless otherwise noted.


## Contributing

We love getting patches! Send us a pull request, or hop on to IRC if
you'd like to chat about something substantial.

[![Build Status](https://travis-ci.org/Kegbot/kegbot.png?branch=master)](https://travis-ci.org/Kegbot/kegbot)

